@@ -24,7 +24,7 @@ def check(
             timegap_lastupdate_now = (now_time - last_update_time).seconds // 60
             if is_all or timegap_lastupdate_now > thres:
                 print(
-                    f"{timegap_lastupdate_now} min! Create! {create_time} Last! {last_update_time} {url}"
+                    f"{run.name:<50}\n \t{timegap_lastupdate_now} min! Create! {create_time} Last! {last_update_time} {url}"
                 )
                 rtn_run.append(run)
     return rtn_run
