@@ -126,7 +126,12 @@ def ls_print_jobs(parsed_jobs, selected_status=None):
             print(df.to_string(index=False))
 
 def collect_job(is_dir, key, ace=2):
-    ace = f"nv-us-west-{ace}"
+    loc = {
+        1: 'nv-us-east',
+        2: 'nv-us-west',
+        3: 'nv-us-west',
+    }[ace]
+    ace = f"{loc}-{ace}"
     team = 'deep-imagination' if is_dir else 'lpr-imagine'
     stdout, stderr = run_simple_command(f'ngc batch list --format_type json --team {team} --ace {ace}')
     if stderr:
@@ -163,6 +168,9 @@ def _ngc_result(
     if 'STARTING' in parsed_jobs:
         del parsed_jobs['STARTING']
     all_jobs = list(itertools.chain.from_iterable(parsed_jobs.values()))
+    if len(all_jobs) == 0:
+        logger.warning('no jobs found')
+        return
     if is_fzf:
         df = pd.DataFrame([job.get_fzf_kv() for job in all_jobs]).sort_values('id', ascending=False)
         fzf_str = df.to_string(index=False).split('\n')
@@ -208,6 +216,9 @@ def _ngc_bash(
     for k, v in parsed_jobs.items():
         if k in ['QUEUED', 'STARTING', 'RUNNING']:
             all_jobs.extend(v)
+    if len(all_jobs) == 0:
+        logger.warning('no job is running')
+        return
     if is_fzf:
         df = pd.DataFrame([job.get_fzf_kv() for job in all_jobs]).sort_values('id', ascending=False)
         fzf_str = df.to_string(index=False).split('\n')
@@ -234,7 +245,7 @@ def _ngc_bash(
     while True:
         rtn_value = os.system(f"ngc batch exec {select_run.job_id}")
         if rtn_value != 0:
-            logger.warning(f"{rtn_value}: ngc batch exec {select_run.job_id} failed, retrying...")
+            logger.warning(f"ERROR VALUE {rtn_value}: ngc batch exec {select_run.job_id} failed, retrying...")
             time.sleep(5)
         else:
             break
@@ -251,6 +262,9 @@ def _ngc_kill(
     for k, v in parsed_jobs.items():
         if k in ['QUEUED', 'STARTING', 'RUNNING']:
             all_jobs.extend(v)
+    if len(all_jobs) == 0:
+        logger.warning('no job to be killed')
+        return
     to_kill = []
     if is_fzf:
         df = pd.DataFrame([job.get_fzf_kv() for job in all_jobs]).sort_values('id', ascending=False)
